@@ -33,8 +33,6 @@
 #include <QWidget>
 
 
-class QVBoxLayout;
-class QHBoxLayout;
 class QGridLayout;
 class QLabel;
 class QPushButton;
